<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Users/language/en_us.lang.php,v 1.18 2005/04/19 14:45:38 ray Exp $
 * Description:  Defines the English language pack for the Users module.
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Usuários',
'LBL_MODULE_TITLE'=>'Usuários: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisa Usuário',
'LBL_LIST_FORM_TITLE'=>'Lista Usuário',
'LBL_NEW_FORM_TITLE'=>'Novo Usuário',
'LBL_CREATE_NEW_USER'=>'Criar Novo Usuário',
'LBL_LOGIN'=>'Login',
'LBL_USER_ROLE'=>'Função',
'LBL_LIST_NAME'=>'Nome',
'LBL_LIST_LAST_NAME'=>'Sobrenome',
'LBL_LIST_USER_NAME'=>'Usuário',
'LBL_LIST_DEPARTMENT'=>'Departamento',
'LBL_LIST_EMAIL'=>'E-Mail',
'LBL_LIST_PRIMARY_PHONE'=>'Fone Principal',
'LBL_LIST_ADMIN'=>'Admin',
'LBL_LIST_CONFIRM_PASSWORD'=>'Confirmar Senha',
'LBL_LIST_USER_NAME_ROLE'=>'ID Usuário , Nome & Função',
'LBL_LIST_SELECT'=>'Selecionar',
'LBL_LIST_PHONE'=>'Fone',
'LBL_LIST_NO'=>'#',

'LBL_ADMINS'=>'Administradores',
'LBL_STD_USERS'=>'Usuários Padrão',

'UserName'=>'Usuário',
'Name'=>'Nome',
'Tools'=>'Ferramentas',


//added for patch2
'LBL_GROUP'=>'Grupo',
'LBL_CURRENCY_NAME'=>'Moeda',

'LBL_NEW_USER_BUTTON_TITLE'=>'Novo Usuário [Alt+N]',
'LBL_NEW_USER_BUTTON_LABEL'=>'Novo Usuário',
'LBL_NEW_USER_BUTTON_KEY'=>'N',
'LBL_DATE_FORMAT'=>'Formato data',

'LBL_ERROR'=>'Erro:',
'LBL_PASSWORD'=>'Senha',
'LBL_USER_NAME'=>'Usuário',
'LBL_CRM_ID'=>'ID CRM',
'LBL_FIRST_NAME'=>'Nome',
'LBL_LAST_NAME'=>'Sobrenome',
'LBL_YAHOO_ID'=>'ID Yahoo!',
'LBL_THEME'=>'Tema',
'LBL_LANGUAGE'=>'Idioma',
'LBL_ADMIN'=>'Admin',
'LBL_OFFICE_PHONE'=>'Fone Comercial',
'LBL_REPORTS_TO'=>'Reporta-se à',
'LBL_OTHER_PHONE'=>'Outro Fone',
'LBL_OTHER_EMAIL'=>'Outro Email',
'LBL_DEPARTMENT'=>'Departamento',
'LBL_STATUS'=>'Status',
'LBL_TITLE'=>'Título',
'LBL_ANY_PHONE'=>'Fone Alternativo:',
'LBL_ANY_EMAIL'=>'E-Mail Alternativo:',
'LBL_ADDRESS'=>'Endereço',
'LBL_CITY'=>'Cidade',
'LBL_STATE'=>'Estado',
'LBL_POSTAL_CODE'=>'CEP',
'LBL_COUNTRY'=>'País',
'LBL_USER_SETTINGS'=>'Configurações Usuário',
'LBL_USER_INFORMATION'=>'Informação Usuário',
'LBL_MOBILE_PHONE'=>'Celular',
'LBL_OTHER'=>'Outro',
'LBL_FAX'=>'Fax',
'LBL_EMAIL'=>'E-mail',
'LBL_HOME_PHONE'=>'Fone Residencial',
'LBL_ADDRESS_INFORMATION'=>'Informação Endereço',
'LBL_CAL_HRFORMAT'=>'Fomato Data Agenda',
'LBL_CAL_DURATION'=>'Dia inicia em',
'LBL_PRIMARY_ADDRESS'=>'Endereço Principal:',

'LBL_CHANGE_PASSWORD_BUTTON_TITLE'=>'Mudar Senha [Alt+P]',
'LBL_CHANGE_PASSWORD_BUTTON_KEY'=>'P',
'LBL_CHANGE_PASSWORD_BUTTON_LABEL'=>'Mudar Senha',
'LBL_LOGIN_BUTTON_TITLE'=>'Login [Alt+L]',
'LBL_LOGIN_BUTTON_KEY'=>'L',
'LBL_LOGIN_BUTTON_LABEL'=>'Login',
'LBL_LOGIN_HISTORY_BUTTON_TITLE'=>'Histórico Login [Alt+H]',
'LBL_LOGIN_HISTORY_BUTTON_KEY'=>'H',
'LBL_LOGIN_HISTORY_BUTTON_LABEL'=>'Histórico Login',
'LBL_LOGIN_HISTORY_TITLE'=>'Usuários: Histórico Login',
'LBL_RESET_PREFERENCES'=>'Restaurar Preferências Padrão',

'LBL_CHANGE_PASSWORD'=>'Mudar Senha',
'LBL_OLD_PASSWORD'=>'Senha Antiga:',
'LBL_NEW_PASSWORD'=>'Nova Senha:',
'LBL_CONFIRM_PASSWORD'=>'Confirme Senha:',
'ERR_ENTER_OLD_PASSWORD'=>'Por favor entre com sua senha antiga.',
'ERR_ENTER_NEW_PASSWORD'=>'Por favor entre com sua nova senha.',
'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Por favor entre com a confirmação de senha.',
'ERR_REENTER_PASSWORDS'=>'Por favor entre novamente com sua senha.  Os valores \"nova senha\" e \"confirme senha\" não combinam.',
'ERR_INVALID_PASSWORD'=>'Você deve especificar um nome de usuário e senha válidos',
'ERR_PASSWORD_CHANGE_FAILED_1'=>'Mudança na senha do usuário falhou ',
'ERR_PASSWORD_CHANGE_FAILED_2'=>' falhou. Nova senha deve ser definida.',
'ERR_PASSWORD_INCORRECT_OLD'=>'Senha antiga incorreta para usuário especificado. Entre novamente com a informação de senha.',
'ERR_USER_NAME_EXISTS_1'=>'O nome de usuário',
'ERR_USER_NAME_EXISTS_2'=>' já existe.  Nomes de usuários duplicados não são permitidos.<br>Mude o nome de usuário de forma que seja único.',
'ERR_LAST_ADMIN_1'=>'O nome de usuário',
'ERR_LAST_ADMIN_2'=>' é o único usuário Admin.  Pelo menos um usuário deve ser o Admininstrador do Sistema.<br>Verifique as configurações do usuário Administrador.',

'ERR_DELETE_RECORD'=>"Um número de registro deve ser especificado para apagar a Organização.",

// Additional Fields for i18n --- Release vtigerCRM 3.2 Patch 2
// Users--listroles.php , createrole.php , ListPermissions.php , editpermissions.php

'LBL_ROLES'=>'Funções',
'LBL_ROLES_SUBORDINATES'=>'Funções e Subordinados',

'LBL_CREATE_NEW_ROLE'=>'Criar Nova Função',
'LBL_INDICATES_REQUIRED_FIELD'=>'Indica Campos Obrigatórios',
'LBL_NEW_ROLE'=>'Nova Função',
'LBL_PARENT_ROLE'=>'Função Pai',

'LBL_LIST_ROLES'=>'Lista Funções',
'LBL_ENTITY_LEVEL_PERMISSIONS'=>'Nível Permissões por Entidade',
'LBL_ENTITY'=>'Entidade',
'LBL_CREATE_EDIT'=>'Criar/Editar',
'LBL_DELETE'=>'Apagar',
'LBL_LEADS'=>'Leads',
'LBL_ACCOUNTS'=>'Organizações',
'LBL_CONTACTS'=>'Contatos',
'LBL_OPPURTUNITIES'=>'Oportunidades',
'LBL_TASKS'=>'Tarefas',
'LBL_CASES'=>'Casos',
'LBL_EMAILS'=>'Emails',
'LBL_NOTES'=>'Documentos',
'LBL_MEETINGS'=>'Reuniões',
'LBL_CALLS'=>'Chamadas',
'LBL_IMPORT_PERMISSIONS'=>'Importar Permissões',
'LBL_IMPORT_LEADS'=>'Importar Leads',
'LBL_IMPORT_ACCOUNTS'=>'Importar Organizações',
'LBL_IMPORT_CONTACTS'=>'Importar Contatos',
'LBL_IMPORT_OPPURTUNITIES'=>'Importar Oportunidades',

'LBL_ROLE_DETAILS'=>'Detalhes da Função',
//added for vtigercrm4 rc
'LBL_FILE'=> 'Nome Arquivo',
'LBL_FILE_TYPE'=>'Tipo Arquivo',
'LBL_UPLOAD'=>'Transferir Arquivo',
'LBL_ATTACH_FILE'=>'Anexar Arquivo',
'LBL_EMAIL_TEMPLATES'=>'Modelos E-mail',
'LBL_TEMPLATE_HEADER'=>'Modelo',
'LBL_TEMPLATE_DETAILS'=>'Detalhes do Modelo',
'LBL_EDIT_TEMPLATE'=>'Editar Modelo',
'LBL_TEMPLATE_FILE'=>'Arquivo do Modelo',
'LBL_EMAIL_TEMPLATES_LIST'=>'Modelos de Comunicação > Modelos E-mail',
'LBL_MAILMERGE_TEMPLATES_LIST'=> '> Modelos de Comunicação > Modelos E-mail Mesclados',
'LBL_MAILMERGE_TEMPLATES_ATTACHMENT' => '> Modelos de Comunicação > Modelo Email Mesclado Anexo',
'LBL_DOWNLOAD_NOW'=>'Download Agora',
'LBL_DOWNLOAD'=>'Download',
'LBL_SELECT_MODULE'=>'Selecione Módulo',
'LBL_MERGE_FILE'=>'Arquivo : ',
'LBL_MERGE_MSG'=>'Selecionar um Módulo para nomear este Modelo',
'LBL_MERGE_FIELDS'=>'Campos Mesclados',
'LBL_COPY_PASTE'=>'Copiar & Colar',
'LNK_GO_TO_TOP'=>'Ir Topo Página',
'LBL_COLON'=>':',
'LBL_EMAIL_TEMPLATE'=>'Modelo E-mail',
'LBL_NEW_TEMPLATE'=>'Novo Modelo',
'LBL_ADD_TEMPLATE'=>'Adicionar Modelo',
'LBL_USE_MERGE_FIELDS_TO_EMAIL_CONTENT'=>'Utilize a mesclagem de campos para personalisar o conteúdo de seu e-mail.',
'LBL_AVAILABLE_MERGE_FIELDS'=>'Campos Unificados Disponíveis',
'LBL_SELECT_FIELD_TYPE'=>'Selecionar Tipo Campo',
'LBL_SELECT_FIELD'=>'Selecionar Campo:',
'LBL_MERGE_FIELD_VALUE'=>'Copia Valor Campo Mesclado:',
'LBL_ACCOUNT_FIELDS'=>'Campos Organização',
'LBL_CONTACT_FIELDS'=>'Campos Contato',
'LBL_LEAD_FIELDS'=>'Campos Lead',
'LBL_COPY_AND_PASTE_MERGE_FIELD'=>'Copie e cole o valor do campo mesclado no Modelo abaixo.',
'LBL_EMAIL_TEMPLATE_INFORMATION'=>'Modelos Comunicação > Modelos E-mail > Visualizando',
'LBL_FOLDER'=>'Pasta',
'LBL_PERSONAL'=>'Pessoal',
'LBL_PUBLIC'=>'Público',
'LBL_TEMPLATE_NAME'=>'Nome Modelo:',
'LBL_SUBJECT'=>'Assunto',
'LBL_BODY'=>'Corpo E-mail',
'LBL_TEMPLATE_TOOLS'=>'Ferramentas',
'LBL_TEMPLATE_PUBLIC'=>'Acesso Público',
'LBL_TEMPLATE_PRIVATE'=>'Acesso Privado',
'LBL_TEMPLATE_SUBJECT'=>'Assunto E-mail',
'LBL_TEMPLATE_MESSAGE'=>'Mensagem E-mail',
'LBL_VIEWING'=>'Visualizando',
'LBL_PROPERTIES'=>'Propriedade de',


//added to fix the issue #6630
'LBL_ASTERISKEXTENSIONS_EXIST' => 'Extensão Asterisk já Existe!',

// Added fields in createnewgroup.php
'LBL_CREATE_NEW_GROUP'=>'Criar Novo Grupo',
'LBL_NEW_GROUP'=>'Novo Grupo',
'LBL_EDIT_GROUP'=>'Editar Grupo',
'LBL_GROUP_NAME'=>'Nome Grupo',
'LBL_GROUP_DETAILS'=>'Detalhes Grupo',
'LBL_MEMBER'=>'Membros',
'LBL_MEMBER_AVLBL'=>'Membros & Entidades Disponíveis',
'LBL_MEMBER_SELECTED'=>'Membros Selecionados',
'LBL_GROUP_MESG1'=>'Os Grupos são um caminho flexivel para conceder direitos de acesso, quando complexos direitos de acesso tiver que ser definido. Você pode combinar multiplas entidades tais como Funções, Usuários, Perfís etc. em um simples Grupo.',
'LBL_GROUP_MESG2'=>'Para adicionar, selecione os membros da Entidade da esquerda e click no botão ">>".',
'LBL_GROUP_MESG3'=>'Para remover, selecione os membros do grupo da direita e click no botão "<<".',


// Added fields in detailViewmailtemplate.html,listgroupmembers.php,listgroups.php
'LBL_DETAIL_VIEW_OF_EMAIL_TEMPLATE'=>'Visão Detalhada do Modelo E-mail',
'LBL_DETAIL_VIEW'=>'Detalhe Visualização de',
'LBL_EDIT_VIEW'=>'Editar Visualização de',
'LBL_EDITING'=>'Editando usuário',
'LBL_GROUP_MEMBERS_LIST'=>'Lista de Membros de Grupo',
'LBL_GROUPS'=>'Grupos',
'LBL_MY_GROUPS'=>'Meus Grupos',
'LBL_ADD_GROUP_BUTTON'=>'Adicionar Grupo',
'LBL_WORD_TEMPLATES'=>'Modelos Mensagem Mesclada',
'LBL_NEW_WORD_TEMPLATE'=>'Novo Modelo',
'LBL_EMAIL_TEMPLATE_DESC'=>'Administrar modelos de email usados para Campanhas e Mensagens em Massa',
'LBL_NAME'=>'Nome',

// Added fields in TabCustomise.php,html and UpdateTab.php,html
'LBL_CUSTOMISE_TABS'=>'Customizar Tabs',
'LBL_CHOOSE_TABS'=>'Escolher TABS',
'LBL_AVAILABLE_TABS'=>'TABS Disponíveis',
'LBL_SELECTED_TABS'=>'TABS Selecionadas',
'LBL_USER'=>'Usuário',
'LBL_TAB_MENU_UPDATED'=>'Menu TAB Atualizado! Por gentileza, siga para',
'LBL_TO_VIEW_CHANGES'=>' para visualizar as mudanças',

// Added to change homepage order
'LBL_CHANGE_HOMEPAGE_LABEL'=>'Ordem da Página Inicial',
'LBL_CHANGE_HOMEPAGE_TITLE'=>'Página Inicial',

// Added fields in binaryfilelist.php
'LBL_OERATION'=>'Operação',

// Added fields in CreateProfile.php
'LBL_PROFILE_NAME'=>'Criar Novo Perfil:',
'LBL_NEW_PROFILE'=>'Novo Perfil',
'LBL_NEW_PROFILE_NAME'=>'Nome Perfil',
'LBL_PARENT_PROFILE'=>'Perfil Pai',
'LBL_BASIC_PROFILE_DETAILS'=>'Detalhes Básicos do Perfil',
'LBL_STEP_1_2'=>'Passo 1 de 2',
'LBL_STEP_2_2'=>'Passo 2 de 2',
'LBL_STEP'=>'Passo',
'LBL_SELECT_BASE_PROFILE'=>'Selecionar Perfil Base',
'LBL_PROFILE_PRIVILEGES'=>'Privilégio Perfil',
'LBL_GLOBAL_PRIVILEGES'=>'Privilégio Global',
'LBL_TAB_PRIVILEGES'=>'Privilégio Aba',
'LBL_FIELD_PRIVILEGES'=>'Privilégio de Campo',
'LBL_STANDARD_PRIVILEGES'=>'Privilégio Padrão',
'LBL_UTILITY_PRIVILEGES'=>'Privilégio Público',
'LBL_UTILITIES'=>'Público',
'LBL_BASE_PROFILE_MESG'=>'Configurar um Perfil Base e editar os privilégios <b>(Recomendado)</b>',
'LBL_BASE_PROFILE'=>'Perfil Base:',
'LBL_OR'=>'OU',
'LBL_BASE_PROFILE_MESG_ADV'=>'Definirei os privilégios a partir do zero <b>(Usuários Avançados)</b>',
'LBL_FOR'=>'para',
'LBL_GLOBAL_MESG_OPTION'=>'Selecionar as opções abaixo para alterar Privilégio Global',
'LBL_VIEW_ALL'=>'Visualizar todos',
'LBL_EDIT_ALL'=>'Editar todos',
'LBL_ALLOW'=>'Permitidos',
'LBL_MESG_VIEW'=>'visualizar todas as informações / Módulos do vtiger CRM',
'LBL_MESG_EDIT'=>'editar todas as informações / Módulos do vtiger CRM',
'LBL_STD_MESG_OPTION'=>'Selecionar as ações padrões para permissão',
'LBL_TAB_MESG_OPTION'=>'Módulos para serem apresentados',
'LBL_UTILITY_MESG_OPTION'=>'Selecionar as ações públicas para permissão',
'LBL_FIELD_MESG_OPTION'=>'Selecionar os campos para permissão',
'LBL_FINISH_BUTTON'=>'Final',
'LBL_PROFILE_DETAIL_VIEW'=>'Visualização detalhes do Perfil',
'LBL_PROFILE_MESG'=>'Visualizar privilégio de acesso para',
'LBL_PROFILE_M'=>'Perfil',
'LBL_DEFINE_PRIV_FOR'=>' Definir Privilégio para ',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Usar as opções abaixo para definir privilégio',
'LBL_SUPER_USER_PRIV'=>'Privilégio Global',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Definir Privilégio para cada Módulo ',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Configurações Campos & Ferramentas',
'LBL_SHOW_FIELDS'=>'Mostrar Campos',
'LBL_TOOLS_TO_BE_SHOWN'=>'Ferramentas para mostrar',
'LBL_WELCOME_PROFILE_CREATE'=>'Bem vindo ao Sistema de Atribuição de Privilégios por Perfil ',
'LBL_SELECT_CHOICE_NEW_PROFILE'=>'Selecionar sua opção para criar novo Perfil',
'LBL_ADD_CUSTOM_RULE'=>'Adicionar Privilégio para Função Customizada',
'LBL_EDIT_CUSTOM_RULE'=>'Editar Privilégio para Funções Customizadas',
'LBL_CLOSE'=>'Fechar',
'LBL_SELECT_ENTITY'=>'Selecionar uma entidade abaixo',
'LBL_CAN_BE_ACCESSED_BY'=>'Pode ser acessado por',
'LBL_PERMISSIONS'=>'Permissões',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Direitos de acesso para Módulos relacionados',
'LBL_RULE_CONSTRUCTION'=>'Tela de Construção de Função',
'LBL_ADD_RULE'=>'Adicionar Função',
'LBL_RELATED_MODULE_RIGHTS'=>'Direitos Módulo Relacionado',
'LBL_IN_PERMISSION'=>'na permissão',

//Added fields in createrole.php
'LBL_HDR_ROLE_NAME'=>'Criar Nova Função:',
'LBL_TITLE_ROLE_NAME'=>'Nova Função',
'LBL_ROLE_NAME'=>'Nome Função',
'LBL_ROLE_PROFILE_NAME'=>'Associado a um Perfil',
'LBL_SPECIFY_ROLE_NAME'=>'Especificar um nome para nova função :',
'LBL_ASSIGN_PROFILE'=>'Determinar Perfil(is)',
'LBL_PROFILE_SELECT_TEXT'=>'Selecionar os Perfis abaixo e clique no botão Nomear',
'LBL_PROFILES_AVLBL'=>'Perfis Disponíveis',
'LBL_ASSIGN_PROFILES'=>'Perfis Nomeados',
'LBL_REPORTS_TO_ROLE'=>'Relatórios para Função',
'LBL_ASSOCIATED_PROFILES'=>'Perfis Associados :',
'LBL_ASSOCIATED_USERS'=>'Usuários Associados :',


//Added fields in OrgSharingDetailsView.php
'LBL_ORG_SHARING_PRIVILEGES'=>'Privilégios Compartilhados na Organização',
'LBL_EDIT_PERMISSIONS'=>'Editar Permissão',
'LBL_SAVE_PERMISSIONS'=>'Salvar Permissão',
'LBL_READ_ONLY'=>'Publico: Só Leitura',
'LBL_EDIT_CREATE_ONLY'=>'Publico: Leitura, Criar/Editar',
'LBL_READ_CREATE_EDIT_DEL'=>'Publico: Leitura, Criar/Editar, Del',
'LBL_PRIVATE'=>'Privado',

//Added fields in listnotificationschedulers.php
'LBL_HDR_EMAIL_SCHDS'=>'Usuários : Notificações por E-mail',
'LBL_EMAIL_SCHDS_DESC'=>'Abaixo está a lista de notificações que são ativadas automaticamente quando o evento correspondente ocorrer.',
'LBL_ACTIVE'=>'Ativo',
'LBL_INACTIVE'=>'Inativo',
'LBL_NOTIFICATION'=>'Notificação',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_TASK_NOTIFICATION'=>'Notificação de Tarefas Atrasadas',
'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Notificação quando uma tarefa está atrasada à mais de 24 h',
'LBL_MANY_TICKETS'=>'Notificação de excesso de Tickets',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Notificar quando for alocado Tickets além do limite a uma entidade em particular, podendo comprometer a qualidade do Serviço',
'LBL_PENDING_TICKETS'=>'Notificação de Tickets Pendentes',
'LBL_TICKETS_DESCRIPTION'=>'Notificação para verificar Tickets que estão pendentes',
'LBL_START_NOTIFICATION'=>'Notificação de Início do Suporte',
'LBL_START_DESCRIPTION'=>'Notificação da situação de início do Suporte/Serviço',
'LBL_BIG_DEAL'=>'Notificação de Grande Negócio',
'LBL_BIG_DEAL_DESCRIPTION'=>'Notificação quando existe um grande negócio',
'LBL_SUPPORT_NOTICIATION'=>'Notificação de Fim do Suporte',
'LBL_SUPPORT_DESCRIPTION'=>'Notificação quando o suporte estiver quase no fim',
'LBL_BUTTON_UPDATE'=>'Atualizar',
'LBL_MODULENAMES'=>'Módulo',

//Added fields in ListFieldPermissions.html
'LBL_FIELD_PERMISSION_FIELD_NAME'=>'Nome Campo',
'LBL_FIELD_PERMISSION_VISIBLE'=>'Visível',
'LBL_FIELD_PERMISSIOM_TABLE_HEADER'=>'Campos Padrões',
'LBL_FIELD_LEVEL_ACCESS'=>'Nível de Acesso ao Campo',

//Added fields after 4.0.1
'LBL_SIGNATURE'=>'Assinatura',

//Added for Event Reminder 4.2 Alpha release
'LBL_ACTIVITY_NOTIFICATION'=>'Notificação Lembrete Evento',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Notificar antes que um evento ocorra baseado no Lembrete',
'LBL_MESSAGE'=>'Messagem',

//Added for Global Privileges

'Public: Read Only'=>'Público: Só Leitura',
'Public: Read, Create/Edit'=>'Público: Ler, Criar/Editar',
'Public: Read, Create/Edit, Delete'=>'Público: Ler, Criar/Editar, Del',
'Private'=>'Particular',
'Hide Details'=>'Omitir Detalhes',
'Hide Details and Add Events'=>'Omitir Detalhes e Adicionar Eventos',
'Show Details'=>'Mostrar Detalhes',
'Show Details and Add Events'=>'Mostrar Detalhes e Adicionar Eventos',

'LBL_USR_CANNOT_ACCESS'=>'Usuários não podem acessar outros usuários ',
'LBL_USR_CAN_ACCESS'=>'Usuários podem ',
'LBL_USR_OTHERS'=>'outros usuários ',

'Read Only '=>'Só Leitura ',
'Read, Create/Edit, Delete '=>'Ler, Criar/Editar, Del ',
'Read, Create/Edit '=>'Ler, Criar/Editar ',
'Read/Write'=>'Leitura/Escrita',
'LBL_GO_TO_TOP'=>'Topo',
'LNK_CLICK_HERE'=>'Clique aqui',
'LBL_RULE_NO'=>'No. Função',
'LBL_CAN_BE_ACCESSED'=>'pode ser acessado por',
'LBL_PRIVILEGES'=>'Privilégios',
'LBL_OF'=>'de',



//Added for 4.2GA support for mail server integration
'LBL_ADD_MAILSERVER_BUTTON_TITLE'=>'Adicionar Servidor de Mensagem',
'LBL_ADD_MAILSERVER_BUTTON_KEY'=>'M',
'LBL_ADD_MAILSERVER_BUTTON_LABEL'=>'Adicionar Servidor de Mensagem',

'LBL_LIST_MAILSERVER_BUTTON_TITLE'=>'Listar Servidor de Mensagem',
'LBL_LIST_MAILSERVER_BUTTON_KEY'=>'L',
'LBL_LIST_MAILSERVER_BUTTON_LABEL'=>'Listar Servidor de Mensagem',
//added for inventory terms and conditions
'INV_TANDC'=>'Prazos & Condições',
'INV_TERMSANDCONDITIONS'=>'Prazos & Condições',
'LBL_INV_TERMSANDCONDITIONS'=>'Gestão de Estoque',


'INVENTORYNOTIFICATION'=>'Notificações de Estoque',
'LBL_INVENTORY_NOTIFICATIONS'=>'Editar E-mail de Notificações de Estoque',
'LBL_INV_NOT_DESC'=>'Esta é a lista de notificações que é enviada para o Almoxarife com relação a procura e a quantidade atual em estoque durante a criação da Cotação, Pedido de Vendas e Fatura.',

'InvoiceNotification'=>'Notificação de Estoque de Produtos durante Geração da Fatura',
'InvoiceNotificationDescription'=>'Quando o nível de produto em estoque ficar abaixo do nível de reposição, uma notificação será enviada para o Almoxarife',

'QuoteNotification'=>'Notificação de Estoque de Produto durante Geração de Cotação',
'QuoteNotificationDescription'=>'Durante a geração da Cotação se o estoque do produto na Loja for menor que a quantidade mencionada na Cotação então esta notificação será enviada para o Almoxarife',

'SalesOrderNotification'=>'Notificação de Estoque de Produto durante Geração do Pedido de Venda',
'SalesOrderNotificationDescription'=>'Durante geração do Pedido de Venda se o estoque do produto na Loja for menor que a quantidade mencionada no Pedido de Venda então esta notificação será enviada para o Almoxarife',

//New addition for 4.2 GA
'LBL_USER_FIELDS'=>'Campos do Usuário',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Nota: Não remova ou altere o valores dentro {  }',

//Added for patch2
'LBL_FILE_INFORMATION'=>'Informação do Arquivo',

//Added after pathc2
'LBL_LEAD_FIELD_ACCESS'=>'Acesso Campos Lead',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Acesso Campos Organização',

'LBL_CONTACT_FIELD_ACCESS'=>'Acesso Campos Contato',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Acesso Campos Oportunidade',

'LBL_HELPDESK_FIELD_ACCESS'=>'Acesso Campos Helpdesk',

'LBL_PRODUCT_FIELD_ACCESS'=>'Acesso Campos Produto',

'LBL_NOTE_FIELD_ACCESS'=>'Acesso Campos Documento',

'LBL_EMAIL_FIELD_ACCESS'=>'Acesso Campos E-Mail',

'LBL_TASK_FIELD_ACCESS'=>'Acesso Campos Tarefa',

'LBL_EVENT_FIELD_ACCESS'=>'Acesso Campos Evento',
'LBL_VENDOR_FIELD_ACCESS'=>'Acesso Campos Fornecedor',
'LBL_PB_FIELD_ACCESS'=>'Acesso Campos Lista de Preços',
'LBL_QUOTE_FIELD_ACCESS'=>'Acesso Campos Cotação',
'LBL_PO_FIELD_ACCESS'=>'Acesso Campos Pedido de Compra',
'LBL_SO_FIELD_ACCESS'=>'Acesso Campos Pedido de Venda',
'LBL_INVOICE_FIELD_ACCESS'=>'Acesso Campos Fatura',

//given for calendar color for an user
'LBL_COLOR'=>'Cores na Agenda',
//added for activity view in home page
'LBL_ACTIVITY_VIEW'=>'Padrão Visualização Atividade',
//Added to change Home page order
'LBL_HOMEPAGE_ORDER_UPDATE'=>'Atualização Ordem dos Blocos na Pagina Principal',
'LBL_HOMEPAGE_ID'=>'Ordem Blocos',
'ERR_INVALID_USER'=>'Acesso Inválido--Por favor chame a partir de Minhas Organizações',
'ALVT'=>'Principais Organizações',
'PLVT'=>'Principais Oportunidades',
'QLTQ'=>'Principais Cotações',
'CVLVT'=>'Métricas Chave',
'HLT'=>'Principais Tickets',
'OLV'=>'Atividades em Aberto',
'GRT'=>'Participação em Grupos',
'OLTSO'=>'Principais Pedidos Vendas',
'ILTI'=>'Principais Faturas',
'HDB'=>'Home Page Painel',
'OLTPO'=>'Principais Pedidos Compra',
'LTFAQ'=>'FAQs Recentes',
'UA'=>'Próximas Atividades',
'PA'=>'Atividades Pendentes',

//Added for 5.0 alpha
'LBL_GROUP_NAME_ERROR'=>'O nome do Grupo já existe!',
'MNL'=>'Novos Leads',
'LBL_LEAD_VIEW'=>'Padrão Visualizão Lead',
'LBL_TAG_CLOUD'=>'Tag Cloud',
'LBL_LIST_TOOLS'=>'Ferramentas',
'LBL_STATISTICS'=>'Estatísticas',
'LBL_TOTAL'=>'Total :',
'LBL_OTHERS'=>'Outros :',
'LBL_USERS'=>'Usuário(s)',
'LBL_USER_LOGIN_ROLE'=>'Login Usuário & Função',
'LBL_USER_MORE_INFN'=>'Mais Informação',
'LBL_USER_ADDR_INFN'=>'Informação Endereço',
'LBL_USER_IMAGE'=>'Imagem Usuário',
'LBL_USR'=>'Usuários',

'LBL_MY'=>'Meu',
'LBL_MY_DEFAULTS'=>'Meus Padrões',
'LBL_MY_DESG'=>'Minhas Funções & Detalhes Contatos',
'LBL_MY_ADDR'=>'Meu Endereço Correspondência',
'LBL_MY_PHOTO'=>'Minha Foto',
'LBL_CHANGE_PHOTO'=>'Mudar Foto...',
'LBL_CHANGE'=>'Mudar',


//Added for Access Privileges

'LBL_GLOBAL_FIELDS_MANAGER'=>'Administrar Campos Globais',
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Privilégios Acesso Global',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Privilégios Acesso Customizado',
'LBL_BOTH'=>'Ambos',
'LBL_VIEW'=>'Visualizar',
'LBL_RECALCULATE_BUTTON'=>'Recalcular',
'LBL_ADD_PRIVILEGES_BUTTON'=>'Adicionar Privilégios',
'LBL_CUSTOM_ACCESS_MESG'=>'Funções para Acesso Customizado não definidas .',
'LBL_CREATE_RULE_MESG'=>'para criar uma nova Função',
'LBL_SELECT_SCREEN'=>'Selecionar a Tela / Módulo :',
'LBL_FIELDS_AVLBL'=>'Campos Disponíveis em',
'LBL_FIELDS_SELECT_DESELECT'=>'Campos a serem apresentados',
'LBL_ROLE_TO_BE_DELETED'=>'Função a ser Apagada',
'LBL_TRANSFER_USER_ROLE'=>'Transferir Usuários para Função',
'LBL_DELETE_ROLE'=>'Apagar Função',
'LBL_MORE_INFORMATION'=>'Mais Informação',
'LBL_USERLOGIN_ROLE'=>'Login & Função do Usuário',
'LBL_USER_IMAGE_INFORMATION'=>'Fotografia do Usuário',

//Added for 5.0 for all fields
'Role'=>'Função',
'Email'=>'E-mail',
'Admin'=>'Admin',
'User Name'=>'Nome Usuário',
'First Name'=>'Nome',
'Last Name'=>'Sobrenome',
'Status'=>'Status',
'Default Activity View'=>'Padrão Visualização Agenda',
'Default Lead View'=>'Padrão Visualização Lead',
'Currency'=>'Moeda',
'Title'=>'Título',
'Office Phone'=>'Fone Escritório',
'Department'=>'Departamento',
'Mobile'=>'Celular',
'Reports To'=>'Reporta-se à',
'Other Phone'=>'Fone Alternativo',
'Other Email'=>'E-mail Alternativo',
'Fax'=>'Fax',
'Yahoo id'=>'ID Yahoo',
'Home Phone'=>'Fone Residencial',
'User Image'=>'Imagem Usuário',
'Date Format'=>'Formato Data',
'Tag Cloud'=>'Tag Cloud',
'Signature'=>'Assinatura',
'Documents'=>'Documentos',
'Street Address'=>'Endereço',
'City'=>'Cidade',
'State'=>'Estado',
'Postal Code'=>'CEP',
'Country'=>'País',
'Password'=>'Senha',
'Confirm Password'=>'Confirmar Senha',
'LBL_SHOWN'=>'Mostrar',
'LBL_HIDDEN'=>'Ocultar',
'LBL_SHOW'=>'Mostrar',
'LBL_HIDE'=>'Ocultar',
'LBL_HOME_PAGE_COMP'=>'Componentes Home Page',
'LBL_LOGIN_HISTORY'=>'Histórico Login',
'LBL_USERDETAIL_INFO'=>'Visualizando detalhes sobre o Usuário',
'LBL_DELETE_GROUP'=>'Apagar Grupo',
'LBL_DELETE_GROUPNAME'=>'Grupo a ser Apagado',
'LBL_TRANSFER_GROUP'=>'Transferir Propriedade para: ',
'LBL_DELETE_USER'=>'Usuário a ser Apagado',
'LBL_TRANSFER_USER'=>'Transferir Propriedade para Usuário',
'LBL_DELETE_PROFILE'=>'Apagar Perfil',
'LBL_TRANSFER_ROLES_TO_PROFILE'=>'Transferir Funções para o Perfil',
'LBL_PROFILE_TO_BE_DELETED'=>'Perfil a ser Apagado',

//Added for disabling window Recalculate

'LBL_RECALC_MSG'=>'Você tem certeza que deseja recalcular Acesso Compatilhado?',
'LBL_YES'=>'Sim',
'LBL_NO'=>'Não',

'LBL_MANDATORY_MSG'=>'Campos Obrigatórios',
'LBL_DISABLE_FIELD_MSG'=>'Campos das Configurações Gerais de Acesso Desabilitados',

//Added for About Us

'LBL_CONTACT_US'=>'Contacte-nos',
'LBL_READ_LICENSE'=>'Ler Licença',
'LBL_VERSION'=>'Versão',
'LBL_TEAM'=>'Equipe',
'LBL_CREDITS'=>'Créditos',
'LBL_THIRD_PARTY'=>'Pacotes de Terceiros',
'LBL_COMMUNITY'=>'E Comunidade vtiger',

'LBL_ASSIGN_ROLE'=>'Atribuir Função',

//Moved from Settings to here for Webmail client integration (for 5.0.3 release)

'LBL_ADD_MAIL_ACCOUNT'=>'Adicionar Organização Correio',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Nova Organização Correio [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Nova Organização Correio',
'LBL_GENERAL_INFO'=>'Informação Geral',
'LBL_DISPLAY_NAME'=>'Nome Exibição',
'LBL_MAIL_PROTOCOL'=>'Protocolo Correio',
'LBL_LIST_PASSWORD'=>'Senha',
'LBL_MAIL_SERVER_NAME'=>'Nome ou IP do Servidor Correio',
'LBL_INCOME_SERVER_SETTINGS'=>'Servidor Recebimento Correio',
'LBL_TEST_SETTINGS'=>'Testar configuração da minha Organização imediatamente',
'LBL_TEST_BUTTON_TITLE'=>'Testar minha Organização agora! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Testar minha Organização agora!',
'LBL_DEFAULT'=>'Padrão',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'Itens marcados com <font color="red">*</font>são requeridos<br>',
'LBL_SSL_OPTIONS'=>'Opções SSL',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'Sem TLS',
'LBL_CERT_VAL'=>'Validações Certificado',
'LBL_INT_MAILER'=>'Usar Sistema Interno envio E-mail?',
'LBL_INT_MAILER_USE'=>'Sim',
'LBL_INT_MAILER_NOUSE'=>'Não',
'LBL_VAL_SSL_CERT'=>'Validar SSL',
'LBL_DONOT_VAL_SSL_CERT'=>'Não Validar SSL',
'LBL_WEB_MAIL_CONFIG'=>'Configuração Webmail',
'LBL_CONFIGURE_WEB_MAIL'=>' - Configurar Webmail',
'LBL_LIST_MAIL_ACCOUNT'=>'  Listar Organização Correio',
'LBL_MY_MAIL_SERVER_DET'=>'Detalhes Servidor Recebimento Mensagem',
'LBL_MY_DETAILS'=>'Meus Detalhes',
'LBL_EMAIL_ID'=>'ID Email',
'LBL_EMAIL_ADDRESS'=>'E-mail',
'LBL_NAME_EXAMPLE'=>'(exemplo : João da Silva)',
'LBL_EMAIL_EXAMPLE'=>'(exemplo : joaosilva@xyz.com.br)',
'LBL_REFRESH_TIMEOUT'=>'Atualizar Timeout',
'LBL_1_MIN'=>'1 minuto',
'LBL_2_MIN'=>'2 minutos',
'LBL_3_MIN'=>'3 minutos',
'LBL_4_MIN'=>'4 minutos',
'LBL_5_MIN'=>'5 minutos',
'LBL_EMAILS_PER_PAGE'=>'Email por Página',
// Added for 5.0.3

'LBL_ENTER_PROFILE'=>'Digite o Nome do Perfil',
'TITLE_USER_DOCUMENT'=>'Documento sem título',
'TITLE_VTIGER_CRM_5'=>'vtiger CRM 5 - Gratuíto, Código Aberto e Uso Comercial',
'ROLE_DRAG_ERR_MSG'=>'Você não pode mover um Nó Pai com um Nó Filho',

'LBL_NOTIFICATION_ACTIVITY'=>'Atividade de Notificação',
'LBL_NOTIFICATION_EMAIL_INFO'=>'Informação E-mail Notificação',
'LBL_GOTO_LISTVIEW_BUTTON'=>'Ir para Lista',

// Added/Updated for vtiger CRM 5.0.4

'LBL_SSL' => 'SSL',
//Added to fix the issue #4081
'LBL_USERNAME_EXIST' => 'Nome Usuário já Existe!',
'LBL_UNAUTHORIZED_ACCESS' => 'Acesso não autorizado para administração de Usuário',
//Added to provide User based TagCloud
'LBL_TAGCLOUD_DISPLAY'=>'Mostrar Tag Cloud',
'INTERNAL_MAIL_COMPOSER'=>'Editor Interno de Mensagens',

// Added for 5.0.4 to Support Email notication on User Creation
'User Login Details'=>'Detalhes Acesso Usuário',
'LBL_TO_LOGIN' => 'para Acesso',

// Added after 5.0.4 GA

'LBL_USER_ADV_OPTIONS'=>'Opções para Usuários Avançados',
'Reminder Interval'=>'Intervalo Lembrete',
'Webservice Access Key'=>'Chave Acesso',

//user-group fixes
'LBL_GROUPNAME_EXIST' => 'Um Grupo com o nome especificado já existe!',
'LBL_PROFILENAME_EXIST' => 'Um Perfil com o nome especificado já existe!',

//Fixed For Asterisk Configration
'Asterisk Configuration' => 'Configuração Asterisk',
'Asterisk Extension' => 'Extensão Asterisk',
' Receive Incoming Calls' => 'Receber Chamadas',

// Added for Create Custom Fields 
'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Criar Campos Customizados para Usuários',
'LBL_USER_CUSTOMFIELDS' => 'Campos Customizados Usuários',
'LBL_CURRENCY_CONFIGURATION'=> 'Configuração Moeda',

//vtiger CRM 5.3.0 RC fields translated by Valmir Carlos Trindade | valmir@ttcasolucoes.com.br
'Digit Grouping Pattern'=>'Padrão Agrupamento Dígitos',
'Decimal Separator'=>'Separador Decimal',
'Symbol Placement'=>'Localização Símbolo',
'Digit Grouping Separator'=>'Separador Agrupamento Dígitos',

//Time zones-Dont change any value
'Kwajalein' => '(UTC-12:00) Data Internacional Linha Oeste',
'Pacific/Midway' => '(UTC-11:00) Hora Coordenada Universal-11',
'Pacific/Samoa' => '(UTC-11:00) Samoa',
'Pacific/Honolulu' => '(UTC-10:00) Hawai',
'America/Anchorage' => '(UTC-09:00) Alaska',
'America/Los_Angeles' => '(UTC-08:00) Hora do Pacífico (US &amp; Canada)',
'America/Tijuana' => '(UTC-08:00) Tijuana, Baixa California',
'America/Denver' => '(UTC-07:00) Hora Montanhas (US &amp; Canada)',
'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
'America/Mazatlan' => '(UTC-07:00) Mazatlan',
'America/Phoenix' => '(UTC-07:00) Arizona',
'America/Regina' => '(UTC-06:00) Saskatchewan',
'America/Tegucigalpa' => '(UTC-06:00) América Central',
'America/Chicago' => '(UTC-06:00) Hora Central (US &amp; Canada)',
'America/Mexico_City' => '(UTC-06:00) Cidade do México',
'America/Monterrey' => '(UTC-06:00) Monterrey',
'America/New_York' => '(UTC-05:00) Hora do Leste (US &amp; Canada)',
'America/Bogota' => '(UTC-05:00) Bogotá, Lima, Quito',
'America/Lima' => '(UTC-05:00) Lima',
'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (East)',
'America/Caracas' => '(UTC-04:30) Caracas',
'America/Halifax' => '(UTC-04:00) Hora Atlântico (Canada)',
'America/Manaus' => '(UTC-04:00) Manaus',
'America/Santiago' => '(UTC-04:00) Santiago',
'America/La_Paz' => '(UTC-04:00) La Paz',
'America/Cuiaba' => '(UTC-04:00) Cuiaba',
'America/Asuncion' => '(UTC-04:00) Assunção',
'America/St_Johns' => '(UTC-03:30) Newfoundland',
'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
'America/Godthab' => '(UTC-03:00) Greenland',
'America/Montevideo' => '(UTC-03:00) Montevideo',
'Atlantic/South_Georgia' => '(UTC-02:00) Mid-Atlantic',
'Atlantic/Azores' => '(UTC-01:00) Azores',
'Atlantic/Cape_Verde' => '(UTC-01:00) Ilhas Cabo Verde',
'Europe/London' => '(UTC) Londres, Edinburgh, Dublin, Lisboa',
'UTC' => '(UTC) Tempo Universal Coordenado, Hora Média de Greenwich',
'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
'Africa/Casablanca' => '(UTC) Casablanca',
'Europe/Belgrade' => '(UTC+01:00) Belgrado, Bratislava, Budapeste, Ljubljana, Praga',
'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb',
'Europe/Brussels' => '(UTC+01:00) Bruxelas, Copenhague, Madrid, Paris',
'Africa/Algiers' => '(UTC+01:00) África Central Oeste',
'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Roma, Estocolmo, Viena',
'Europe/Minsk' => '(UTC+02:00) Minsk',
'Africa/Cairo' => '(UTC+02:00) Cairo',
'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Vilnius',
'Europe/Athens' => '(UTC+02:00) Atenas, Bucareste',
'Europe/Istanbul' => '(UTC+02:00) Istanbul',
'Asia/Jerusalem' => '(UTC+02:00) Jerusalém',
'Asia/Amman' => '(UTC+02:00) Amman',
'Asia/Beirut' => '(UTC+02:00) Beirute',
'Africa/Windhoek' => '(UTC+02:00) Windhoek',
'Africa/Harare' => '(UTC+02:00) Harare',
'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riyadh',
'Asia/Baghdad' => '(UTC+03:00) Bagdad',
'Africa/Nairobi' => '(UTC+03:00) Nairobi',
'Asia/Tehran' => '(UTC+03:30) Tehran',
'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
'Europe/Moscow' => '(UTC+04:00) Moscou, Volgograd',
'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muscat',
'Asia/Baku' => '(UTC+04:00) Baku',
'Asia/Yerevan' => '(UTC+04:00) Yerevan',
'Asia/Karachi' => '(UTC+05:00) Islamabad, Karachi',
'Asia/Tashkent' => '(UTC+05:00) Tashkent',
'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, Nova Deli',
'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
'Asia/Dhaka' => '(UTC+06:00) Dhaka',
'Asia/Almaty' => '(UTC+06:00) Almaty',
'Asia/Yekaterinburg' => '(UTC+06:00) Ekaterinburg',
'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangoon)',
'Asia/Novosibirsk' => '(UTC+07:00) Novosibirsk',
'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
'Asia/Brunei' => '(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi',
'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnoyarsk',
'Asia/Ulaanbaatar' => '(UTC+08:00) Ulaan Bataar',
'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Singapore',
'Asia/Taipei' => '(UTC+08:00) Taipei',
'Australia/Perth' => '(UTC+08:00) Perth',
'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
'Asia/Seoul' => '(UTC+09:00) Seoul',
'Asia/Tokyo' => '(UTC+09:00) Toquio',
'Australia/Darwin' => '(UTC+09:30) Darwin',
'Australia/Adelaide' => '(UTC+09:30) Adelaide',
'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
'Australia/Brisbane' => '(UTC+10:00) Brisbane',
'Australia/Hobart' => '(UTC+10:00) Hobart',
'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
'Asia/Yakutsk' => '(UTC+10:00) Yakutsk',
'Pacific/Fiji' => '(UTC+12:00) Fiji',
'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
'Pacific/Auckland' => '(UTC+12:00) Auckland',
'Asia/Magadan' => '(UTC+12:00) Magadan',
'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',

'Theme'=>'Tema',
'Language'=>'Idioma',
'Secondary Email'=>'Email Secundário',
'Time Zone'=>'Fuso Horário',

);

?>
